#include <cvidef.h>

/*= <Rohde & Schwarz - Audio Analyzer UPL> Include File =====================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/

#ifndef __rsupl_HEADER
#define __rsupl_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif


/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_INSTR_ERROR_OFFSET           (_VI_ERROR+0x3FFC0900L)
#define VI_ERROR_INTERPRETING_RESPONSE  (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9       (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10      (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11      (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12      (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13      (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14      (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15      (_VI_ERROR+0x3FFC080FL)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_PARAMETER16            (_VI_ERROR+0x3FFC0810L)
#define VI_ERROR_INSTR_PARAMETER17            (_VI_ERROR+0x3FFC0811L)
#define VI_RSUPL_ERROR_INSTRUMENT_ERROR       (_VI_ERROR+0x3FFC0900L)
#define VI_RSUPL_ERROR_ANALYZER_FUNCTION      (_VI_ERROR+0x3FFC0910L)
#define VI_RSUPL_ERROR_BLOCK_DATA             (_VI_ERROR+0x3FFC0920L)

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/
ViStatus _VI_FUNC rsupl_init (ViRsrc resourceName, ViBoolean IDQuery,
                    ViBoolean resetDevice, ViPSession instrSession);
ViStatus _VI_FUNC rsupl_applicGenOutSine (ViSession instrSession,
                                          ViBoolean channel, ViReal64 frequencyHz,
                                          ViReal64 levelV, ViReal64 DCOffsetV);
ViStatus _VI_FUNC rsupl_confGenAnStp (ViSession instrSession, ViInt32 channel,
                    ViBoolean output, ViInt32 outputImpedance, ViReal64 levelLimit,
                    ViReal64 referenceFrequencyHz, ViReal64 referenceLevel, 
                    ViInt32 levelLimUnit, ViInt32 refLevelUnit);
ViStatus _VI_FUNC rsupl_confGenDigStp (ViSession instrSession, ViInt32 srcMode,
                    ViInt32 channel, ViReal64 phaseOffset, ViBoolean unbalancedOut,
                    ViBoolean cableSimulator, ViReal64 levelLimit,
                    ViReal64 referenceFrequencyHz, ViReal64 referenceLevel, 
                    ViInt32 audioBits, ViReal64 unbalLevel, ViInt32 unbalLevelUnit,
                    ViInt32 levelLimitUnit, ViInt32 refLevelUnit,
                    ViInt32 phaseOffsetUnit);
ViStatus _VI_FUNC rsupl_confGenDigSync (ViSession instrSession, ViInt32 syncOut,
                    ViInt32 inputSyncSource, ViBoolean syncSignalType,
                    ViInt32 referenceOut, ViBoolean outputData,
                    ViInt32 samplingFrequency, ViReal64 samplingFreqValueHz,
                    ViInt32 inputSyncMode);
ViStatus _VI_FUNC rsupl_confGenDigProtocol (ViSession instrSession,
                    ViBoolean validChannel, ViInt32 chanStatusDataLeft,
                    ViString fileNameLeft, ViString fileNameRight,
                    ViBoolean userData, ViString fileNameUserData,
                    ViInt32 protocolMode, ViInt32 chanStatusDataRight);
ViStatus _VI_FUNC rsupl_confGenFuncSin (ViSession instrSession,
                    ViBoolean freqOffset, ViReal64 frequency, ViInt32 freqUnit,
                    ViBoolean DCOffset, ViReal64 DCOffsetValue,
                    ViInt32 DCOffsetUnit, ViReal64 level, ViInt32 levelUnit,
                    ViBoolean equalizer, ViString fileNameEqualizer,
                    ViBoolean dither, ViReal64 ditherValue, ViInt32 ditherUnit,
                    ViInt32 PDF, ViBoolean lowDistortionGen);
ViStatus _VI_FUNC rsupl_confGenFuncMult (ViSession instrSession,
                    ViReal64 totalGaindB, ViInt32 numbOfWfms,
                    ViBoolean multisineMode, ViReal64 _VI_FAR levelArray[],
                    ViInt32 levelUnit, ViBoolean spacing,
                    ViReal64 spacingValueHz, ViReal64 _VI_FAR frequencyArray[],
                    ViInt32 freqUnit, ViBoolean DCOffset,
                    ViReal64 DCOffsetValue, ViInt32 DCOffsetUnit,
                    ViBoolean equalizer, ViString fileNameEqualizer);
ViStatus _VI_FUNC rsupl_confGenFuncBurs (ViSession instrSession,
                    ViBoolean DCOffset, ViReal64 DCOffsetValue,
                    ViInt32 DCOffsetUnit, ViReal64 frequency,
                    ViInt32 freqUnit, ViReal64 onTime,
                    ViInt32 onTimeUnit, ViReal64 level,
                    ViInt32 levelUnit, ViReal64 burstOnDelay,
                    ViInt32 delayUnit, ViReal64 lowLevel,
                    ViInt32 lowLevelUnit, ViReal64 interval,
                    ViInt32 intervalUnit);
ViStatus _VI_FUNC rsupl_confGenFuncBurs2 (ViSession instrSession,
                    ViBoolean DCOffset,
                    ViReal64 DCOffsetValue,
                    ViInt32 DCOffsetUnit, ViReal64 frequency,
                    ViInt32 freqUnit, ViReal64 onTime,
                    ViInt32 onTimeUnit, ViReal64 level,
                    ViInt32 levelUnit, ViReal64 burstOnDelay,
                    ViInt32 delayUnit, ViReal64 interval,
                    ViInt32 intervalUnit);
ViStatus _VI_FUNC rsupl_confGenFuncModDist (ViSession instrSession,
                    ViBoolean DCOffset,
                    ViReal64 DCOffsetValue,
                    ViInt32 DCOffsetUnit,
                    ViReal64 totalLevel, ViInt32 levelUnit,
                    ViReal64 levelLFUF,
                    ViBoolean freqOffset,
                    ViReal64 lowerFrequency,
                    ViReal64 upperFrequency,
                    ViInt32 freqUnit, ViBoolean dither,
                    ViReal64 ditherValue,
                    ViInt32 ditherUnit, ViInt32 PDF);
ViStatus _VI_FUNC rsupl_confGenFuncDFD (ViSession instrSession,
                    ViBoolean DCOffset, ViReal64 DCOffsetValue,
                    ViInt32 DCOffsetUnit, ViReal64 totalLevel,
                    ViInt32 levelUnit, ViBoolean freqOffset,
                    ViReal64 meanUpperFrequency,
                    ViReal64 differenceFrequency,
                    ViInt32 freqUnit, ViBoolean dither,
                    ViReal64 ditherValue, ViInt32 ditherUnit,
                    ViInt32 PDF, ViBoolean genMode,
                    ViBoolean equalizer,
                    ViString fileNameEqualizer);
ViStatus _VI_FUNC rsupl_confGenFuncRnd (ViSession instrSession,
                    ViBoolean DCOffset, ViReal64 DCOffsetValue,
                    ViInt32 DCOffsetUnit, ViBoolean level,
                    ViReal64 levelValue, ViInt32 levelUnit,
                    ViBoolean spacing, ViReal64 spacingValueHz,
                    ViReal64 lowerFreqWhiteHz,
                    ViReal64 upperFreqWhiteHz,
                    ViReal64 meanFreq13OctHz, ViInt32 shape,
                    ViString fileNameShape, ViInt32 PDF,
                    ViBoolean domain, ViBoolean equalizer,
                    ViString fileNameEqualizer);
ViStatus _VI_FUNC rsupl_confGenFuncArb (ViSession instrSession,
                    ViBoolean DCOffset, ViReal64 DCOffsetValue,
                    ViInt32 DCOffsetUnit, ViBoolean levelType,
                    ViReal64 levelValue, ViInt32 levelUnit,
                    ViString fileName);
ViStatus _VI_FUNC rsupl_confGenFuncPol (ViSession instrSession,
                    ViBoolean DCOffset, ViReal64 DCOffsetValue,
                    ViReal64 levelValue, ViInt32 DCOffsetUnit,
                    ViInt32 levelUnit);
ViStatus _VI_FUNC rsupl_confGenSweConf (ViSession instrSession,
                    ViInt32 sweepControl, ViInt32 nextStep, ViReal64 dwellTimes,
                    ViString fileNameDwell, ViInt32 XAxis, ViInt32 ZAxis,
                    ViString fileNameXAxis, ViString fileNameZAxis);
ViStatus _VI_FUNC rsupl_confGenSweFreq (ViSession instrSession,
                    ViReal64 startFrequency, ViReal64 stopFrequency,
                    ViReal64 pointsStepWidth, ViInt32 spacing, ViBoolean axis, 
                    ViInt32 freqUnit, ViInt32 stepUnit);
ViStatus _VI_FUNC rsupl_confGenSweLev (ViSession instrSession,
                    ViReal64 startLevel, ViReal64 stopLevel, ViReal64 pointsStepWidth, 
                    ViInt32 spacing, ViBoolean axis, ViInt32 levelUnit,
                    ViInt32 stepUnit);
ViStatus _VI_FUNC rsupl_confGenSweOnTm (ViSession instrSession,
                    ViReal64 startOnTime, ViReal64 stopOnTime,
                    ViReal64 pointsStepWidth, ViInt32 spacing, ViBoolean axis, 
                    ViInt32 onTimeUnit, ViInt32 stepUnit);
ViStatus _VI_FUNC rsupl_confGenSweInt (ViSession instrSession,
                    ViReal64 startInterval, ViReal64 stopInterval,
                    ViReal64 pointsStepWidth, ViInt32 spacing, ViBoolean axis, 
                    ViInt32 intervalUnit, ViInt32 stepUnit);
ViStatus _VI_FUNC rsupl_confAnalyzerAnalStp (ViSession instrSession,
                    ViReal64 refImp, ViInt32 channels,
                    ViBoolean chan1Inp, ViBoolean chan2Inp,
                    ViInt32 chan1Imp, ViInt32 chan2Imp, ViBoolean chan1Com,
                    ViBoolean chan2Com, ViInt32 chan1RangMode,
                    ViInt32 chan2RangMode, ViInt32 chan1Range,
                    ViInt32 chan2Range, ViBoolean instrType);
ViStatus _VI_FUNC rsupl_confAnalyzerDigStp (ViSession instrSession,
                    ViInt32 measMode, ViInt32 channels, ViInt32 jitterRef, 
                    ViInt32 input, ViBoolean syncTo, ViReal64 samplingFreqValHz,
                    ViInt32 samplingFrequency, ViInt32 audioBits);
ViStatus _VI_FUNC rsupl_confAnalyzerFFT (ViSession instrSession, ViInt32 window,
                    ViInt32 FFTSize, ViReal64 betaFactor);
ViStatus _VI_FUNC rsupl_confAnalyzerSettl (ViSession instrSession,
                    ViInt32 settlingType, ViInt32 samples, ViReal64 tolerance,
                    ViBoolean toleranceUnit, ViReal64 resolution, 
                    ViInt32 resolutionUnit, ViReal64 timeouts, ViInt32 parameter);
ViStatus _VI_FUNC rsupl_confAnalyzerTrig (ViSession instrSession,
                    ViInt32 startCondition, ViReal64 delays, ViInt32 points, 
                    ViReal64 minLevel, ViInt32 minLevelUnit, ViReal64 times,
                    ViReal64 variation, ViReal64 startValue, ViReal64 stopValue,
                    ViInt32 startStopValueUnit);
ViStatus _VI_FUNC rsupl_confAnalyzerFilterUser (ViSession instrSession,
                    ViInt32 filterType, ViInt32 userFilterNumber,
                    ViReal64 passbandFreqHz, ViReal64 passbandLowFreqHz,
                    ViReal64 passbandHighFreqHz, ViReal64 centerFreqHz,
                    ViReal64 freqWidthHz, ViReal64 attenuationdB,
                    ViString fileName, ViReal64 delays);
ViStatus _VI_FUNC rsupl_confAnalyzerFilterSel (ViSession instrSession,
                    ViInt32 filter1, ViInt32 filter2, ViInt32 filter3);

ViStatus _VI_FUNC rsupl_confAnalyzerSingleFilterSel (ViSession instrSession,
                                                     ViInt32 filterNumber,
                                                     ViInt32 filter);

ViStatus _VI_FUNC rsupl_confAnalyzerLimit (ViSession instrSession,
                    ViInt32 limitCheckMode, ViInt32 limitCheckObject,
                    ViBoolean upperLimit, ViBoolean lowerLimit,
                    ViString fileNameUpperLimit,
                    ViString fileNameLowerLimit, ViReal64 upperLimitValue,
                    ViReal64 lowerLimitValue, ViInt32 upperLimitUnit,
                    ViInt32 lowerLimitUnit);
ViStatus _VI_FUNC rsupl_confAnalyzerProtocolAnl (ViSession instrSession,
                    ViInt32 source, ViInt32 protocolFormat,
                    ViString fileName);
ViStatus _VI_FUNC rsupl_confAnalyzerMeasInpDisp (ViSession instrSession,
                    ViInt32 display, ViInt32 unitChan1, ViInt32 unitChan2,
                    ViInt32 reference, ViReal64 referenceValue,
                    ViInt32 referenceValueUnit);
ViStatus _VI_FUNC rsupl_confAnalyzerMeasInpFreq (ViSession instrSession,
                    ViInt32 display, ViInt32 unitChan1, ViInt32 unitChan2,
                    ViInt32 freqReference, ViReal64 freqReferenceValueHz,
                    ViInt32 phaseReference, ViReal64 phaseReferenceValues,
                    ViInt32 phaseFormat, ViInt32 phasUnit);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncOff (ViSession instrSession);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncRMSSN (ViSession instrSession,
                    ViBoolean SNMeasure, ViInt32 measTime,
                    ViReal64 measTimeValues, ViInt32 unitChan1,
                    ViInt32 unitChan2, ViReal64 triggerLevel,
                    ViBoolean triggerLevelUnit, ViInt32 reference,
                    ViReal64 referenceValue, ViInt32 referenceValueUnit,
                    ViInt32 notchGain, ViInt32 notchFreq,
                    ViReal64 notchFreqValueHz);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncRMSSel (ViSession instrSession,
                    ViInt32 measTime, ViReal64 measTimeValues,
                    ViInt32 unitChan1, ViInt32 unitChan2, ViInt32 freqMode,
                    ViReal64 frequencyValueHz, ViReal64 genTracFactor, ViInt32 reference,
                    ViReal64 referenceValue, ViInt32 referenceValueUnit,
                    ViInt32 notchGain, ViInt32 bandwidth,
                    ViReal64 bandwidthValueHz);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncRMSSwe (ViSession instrSession,
                    ViInt32 spacing, ViReal64 startFrequencyHz,
                    ViReal64 stopFrequencyHz, ViReal64 pointsStepWidth,
                    ViInt32 sweepControl, ViInt32 stepUnit,
                    ViString fileName);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncPeak (ViSession instrSession,
                    ViBoolean SNMeasure, ViInt32 measMode, ViInt32 unitChan1,
                    ViInt32 unitChan2, ViInt32 intervalTime,
                    ViReal64 intervalTimeValues, ViInt32 reference,
                    ViReal64 referenceValue, ViInt32 referenceValueUnit);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncQPeak (ViSession instrSession,
                    ViBoolean SNMeasure, ViInt32 unitChan1, ViInt32 unitChan2,
                    ViInt32 intervalTime, ViReal64 intervalTimeValues,
                    ViInt32 reference, ViReal64 referenceValue,
                    ViInt32 referenceValueUnit, ViInt32 notchGain,
                    ViInt32 notchFreq, ViReal64 notchFreqValueHz);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncDC (ViSession instrSession,
                    ViInt32 measTime, ViInt32 unitChan1, ViInt32 unitChan2,
                    ViInt32 reference, ViReal64 referenceValue,
                    ViInt32 referenceValueUnit, ViReal64 measTimeValues);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncTHD (ViSession instrSession,
                    ViBoolean fundamentalFreq,
                    ViReal64 fundamentalFreqValueHz, ViInt32 chanUnit,
                    ViBoolean dynamicMode, ViInt32 measMode,
                    ViReal64 referenceValue, ViInt32 referenceValueUnit,
                    ViInt32 harmonics);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncTHDN (ViSession instrSession,
                    ViBoolean fundamentalFreq,
                    ViReal64 fundamentalFreqValueHz, ViInt32 chanUnit,
                    ViBoolean dynamicMode, ViInt32 measMode,
                    ViBoolean rejection, ViReal64 freqLimitLowHz,
                    ViReal64 freqLimitHighHz, ViReal64 referenceValue,
                    ViInt32 referenceValueUnit);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncModDist (ViSession instrSession,
                    ViInt16 chanUnit, ViBoolean dynamicMode);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncDFD (ViSession instrSession,
                    ViInt32 chanUnit, ViBoolean dynamicMode, ViInt32 measMode);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncWF (ViSession instrSession,
                    ViBoolean weighting, ViInt32 standard);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncPol (ViSession instrSession);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncFFT (ViSession instrSession,
                    ViBoolean averagingMode, ViInt32 zoom,
                    ViReal64 centerFreqHz, ViInt32 unitChan1,
                    ViInt32 unitChan2, ViInt32 FFTSize,
                    ViInt32 averagingCount, ViInt32 reference,
                    ViReal64 referenceValue, ViInt32 referenceValueUnit,
                    ViInt32 window, ViInt32 notchGain, ViInt32 notchFreq,
                    ViReal64 notchFreqValueHz, ViReal64 betaFactor);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncWfm (ViSession instrSession,
                    ViBoolean measMode, ViInt32 compressionFactor,
                    ViInt32 interpolation, ViInt32 chanUnit,
                    ViReal64 traceLengths, ViReal64 referenceLevel,
                    ViInt32 referenceLevelUnit, ViBoolean triggerSlope,
                    ViReal64 triggerLevel, ViInt32 triggerLevelUnit,
                    ViInt32 triggerSource);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncFiltSim (ViSession instrSession,
                    ViInt32 unit);
ViStatus _VI_FUNC rsupl_confAnalyzerFuncProt (ViSession instrSession);
ViStatus _VI_FUNC rsupl_confSaveRecallSetup (ViSession instrSession,
                    ViBoolean setupMode, ViString fileName,
                    ViBoolean fileAttribute, ViBoolean setupType);
ViStatus _VI_FUNC rsupl_confInstrVer (ViSession instrSession,
                    ViChar _VI_FAR softwareVersion[], ViChar _VI_FAR setupVersion[],
                    ViChar _VI_FAR analogBoardVersion[], ViChar _VI_FAR CPUVersion[],
                    ViChar _VI_FAR digitalBoardVersion[]);
ViStatus _VI_FUNC rsupl_confInstrOpt (ViSession instrSession,
                    ViChar _VI_FAR remoteControl[], ViChar _VI_FAR digitalIO[],
                    ViChar _VI_FAR digitalAudioProtocol[],
                    ViChar _VI_FAR lowDistortionGenerator[],
                    ViChar _VI_FAR audioMonitor[],
                    ViChar _VI_FAR jitterandInterfaceTest[],
                    ViChar _VI_FAR universalSequenceController[]);
ViStatus _VI_FUNC rsupl_confInstrTrig (ViSession instrSession,
                    ViBoolean triggerMode);
ViStatus _VI_FUNC rsupl_confInstrAudioMonitor (ViSession instrSession,
                                               ViBoolean speakerState,
                                               ViInt32 speakerSource,
                                               ViBoolean phonesMode,
                                               ViReal64 speakerGain,
                                               ViReal64 speakerVolume);
ViStatus _VI_FUNC rsupl_confInstrCalibr (ViSession instrSession,
                    ViInt32 generatorCalibration, ViInt32 analyzerCalibration,
                    ViInt32 digitalCalibration);
ViStatus _VI_FUNC rsupl_confInstrDisplay (ViSession instrSession,
                                          ViBoolean display, ViBoolean cursors);
ViStatus _VI_FUNC rsupl_confInstrSense (ViSession instrSession,
                                        ViBoolean sense1, ViBoolean sense2,
                                        ViBoolean sense3);
ViStatus _VI_FUNC rsupl_confStoreData (ViSession instrSession, ViInt32 dataType,
                    ViReal64 normalizingFreqHz, ViString fileName,
                    ViBoolean dataFormat, ViBoolean levelSource, ViBoolean invert1n);
ViStatus _VI_FUNC rsupl_confInstrScreenToFile (ViSession instrSession,
                    ViBoolean fileType, ViString fileName);
ViStatus _VI_FUNC rsupl_dataStoreDel (ViSession instrSession, ViString fileName);
ViStatus _VI_FUNC rsupl_dataStoreCopy (ViSession instrSession, ViString sourceFileName, ViString targetFileName);
ViStatus _VI_FUNC rsupl_dataStoreDir (ViSession instrSession,
                    ViString path);
ViStatus _VI_FUNC rsupl_dataReadBlock (ViSession instrSession, ViInt32 variable,
                    ViReal64 _VI_FAR blockData[], ViPInt32 numberOfValuesRead);
ViStatus _VI_FUNC rsupl_dataWriteBlock (ViSession instrSession,
                    ViInt32 variable, ViReal64 _VI_FAR blockData[],
                    ViInt32 numberOfValuesToWrite);
ViStatus _VI_FUNC rsupl_measSingleCh (ViSession instrSession, ViBoolean channel,
                    ViInt32 variable, ViPReal64 measuredValue);
ViStatus _VI_FUNC rsupl_measDualCh (ViSession instrSession, ViInt32 variable,
                                    ViPReal64 measuredValueCh1,
                                    ViPReal64 measuredValueCh2);
ViStatus _VI_FUNC rsupl_measProtocol (ViSession instrSession,
                    ViChar _VI_FAR channelStatus[], ViChar _VI_FAR LRChannelData[],
                    ViChar _VI_FAR validityBitRight[], ViChar _VI_FAR generalErrors[],
                    ViChar _VI_FAR validityBitLeft[], ViPInt32 parityErrors, 
                    ViPInt32 CRCErrorsLeft, ViPInt32 CRCErrorsRight);
ViStatus _VI_FUNC rsupl_measLimit (ViSession instrSession, ViPInt32 limitFail);
ViStatus _VI_FUNC rsupl_setFreqLevel (ViSession instrSession,
                                      ViBoolean setFrequency, ViReal64 frequency,
                                      ViInt32 frequencyUnit, ViBoolean setLevel,
                                      ViReal64 level, ViInt32 levelUnit);
ViStatus _VI_FUNC rsupl_sendTrig (ViSession instrSession);
ViStatus _VI_FUNC rsupl_step (ViSession instrSession, ViBoolean direction);
ViStatus _VI_FUNC rsupl_abort (ViSession instrSession);
ViStatus _VI_FUNC rsupl_screenToFile (ViSession instrSession);
ViStatus _VI_FUNC rsupl_operationComplete (ViSession instrSession,
                    ViInt32 maxTimeouts);
ViStatus _VI_FUNC rsupl_writeInstrData (ViSession instrSession, ViString writeBuffer);
ViStatus _VI_FUNC rsupl_readInstrData (ViSession instrSession,
                    ViInt32 numberBytesToRead, ViChar _VI_FAR readBuffer[],
                    ViPInt32 numBytesRead);
ViStatus _VI_FUNC rsupl_reset (ViSession instrSession);
ViStatus _VI_FUNC rsupl_self_test (ViSession instrSession,
                    ViPInt16 selfTestResult, ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rsupl_error_query (ViSession instrSession, ViPInt32 errorCode,
                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rsupl_error_message (ViSession instrSession,
                    ViStatus errorCode, ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rsupl_revision_query (ViSession instrSession,
                    ViChar _VI_FAR instrumentDriverRevision[],
                    ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rsupl_close (ViSession instrSession);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
